FramingMath class

Constructors

FramingMath()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clampHotspotToCrop(Hotspot hotspot, CropRect crop) → Hotspot
frameGeometry({required Size boxSize, required Size sourceSize, required CropRect crop, required Hotspot hotspot, required BoxFit fit, double? scale, Offset? offset}) FrameGeometry
previewAlignment({required CropRect crop, required Hotspot hotspot}) Alignment